This is a helper function to remove weathercan's cache directory. This folder contains updated stations inventory lists and the full dataset of Climate normals for 1991-2010.
This is a helper function to remove weathercan's cache directory. This folder contains updated stations inventory lists and the full dataset of Climate normals for 1991-2010.