List of climate normals measurements and types for each set of normals
Source:R/data.R
normals_measurement_types.RdA data frame listing the climate normals measurements classified by
measurement_type available for each set of climate normals. This is very
similar to normals_measurements and just omits the stations.