An index matching variables named in weathercan and downloaded with the
normals_dl() function to those in the original old (1981-2010 and
1971-2000) climate normals data from ECCC.
Format
A data frame with 18 rows and 3 variables:
- ECCC
Original variable name from ECCC
- weathercan
R-compatible name given when formating the data with the
normals_dl()function